checkRequire("Lua_GuideArrow");
checkRequire("Lua_NpcTalkBaseWindow");
checkRequire("Lua_RewardItem");
Lua_NpcTaskWindow = class("Lua_NpcTaskWindow", Lua_NpcTalkBaseWindow);
function Lua_NpcTaskWindow:ctor()
	self:superCall("ctor");

	self.blackAlpha = 180 / 255;
	self.showClose = false;
	self.isClickClose = true;

	self.windowName = "Lua_NpcTaskWindow";
	self.skinName = "NpcTaskWindow_skin";
end

function Lua_NpcTaskWindow:buildShowItem()
	self:superCall("buildShowItem");

	LuaUtil.setObjPos(self.content, 0, -MainWinDefine.V_height / 2 + 360, 0);

	self.autoContinueTxt:setEnable(false);
	self.npcImg:setEnable(false);

	self.npcWinBg.clickScale = false;
	self.npcWinBg:addClickFuntion(self, self.onBgClick);

	self.getRewardBtn:addClickFuntion(self, self.onGetRewardClick);
		
	self.rItem = Lua_RewardItem.new(self.content);
	self.rItem.pivot = 2;
	self.rItem:setLayout(72, 72, 4);
	self.rItem:setMaxShow(4);
	self.rItem:setDepth(10);
	self.rItem:setClickWin(true);
	self.rItem:setMouseEnble(true);
	self.rItem:setItemScale(0.8, 0.8);
	self.rItem:setLocation(150, -285, 0);
end

function Lua_NpcTaskWindow:showWin(param)
	self:superCall("showWin", param);

	local npcData = param.npc;
	self.npcNameTxt.text = npcData.kind;
	if npcData.imgUrl ~= nil then
		self.npcImg:SetDimensions(0, 0);
		self.npcImg:setUrl(npcData.imgUrl);
		self.npcImg:setEnable(true);
	end

	self.taskVo = param.taskVo;
	self.taskNameTxt.text = self.taskVo.curUIDesc.title;
	self.descTxt.text = self.taskVo.curUIDesc.decs;

	if self.taskVo.sound_id ~= nil then
		AudioManager.playNpcSound(self.taskVo.sound_id);
	end
	
	if getLanType() == 2 and self.taskVo.taskType == Lua_TaskDefine.ROUTINE then
		self.getRewardBtn:setBtnEnable(true);
		self.getRewardBtn.label = LanUtil.getValue(123606);
	elseif self.taskVo.status == Lua_TaskDefine.ACCEPT  then
		self.getRewardBtn:setBtnEnable(true);
		self.getRewardBtn.label = LanUtil.getValue(122900);
		
	elseif self.taskVo.status == Lua_TaskDefine.ACCEPTED  then
		self.getRewardBtn:setBtnEnable(false);
		self.getRewardBtn.label = LanUtil.getValue(122901);		
	else
		self.getRewardBtn:setBtnEnable(true);
		self.getRewardBtn.label = LanUtil.getValue(122901);
	end
		
	if self.taskVo.taskType ~= Lua_TaskDefine.ROUTINE then
		self.rItem:setRewardByRewardList(Array(self.taskVo.awardId));
	else
		local roleLvl = DataCenter.roleData.level;
		local expRewards = getConfig({"routine_ordinary_rewards", roleLvl});
		local itemsList = Array();
		if expRewards ~= nil and DataCenter.taskData.routineIsAllComplete ~= 1  then			
			itemsList:add({id = Lua_MoneyData.EXP, count = tonumber(expRewards["exp_value_"..self.taskVo.config.under_task_type]), bind = 0});	
			itemsList:add({id = Lua_MoneyData.COPPER, count = tonumber(expRewards["money_value_"..self.taskVo.config.under_task_type]), bind = 0});		
		end
		self.rItem:setRewardByArray(itemsList);
	end
	
	if self.taskVo.status == Lua_TaskDefine.DELIVERED then
		self.endTime = getTime() + 10;
		self:addTimer("autoGetReward", 0.5, self, self.checkAutoGet);
	elseif self.taskVo.taskType == Lua_TaskDefine.ROUTINE and getLanType() == 2 then
		self.endTime = getTime() + 10;
		self:addTimer("autoGetReward", 0.5, self, self.checkAutoGet);
	end
	self:checkShowGetRewardArrow();
end

function Lua_NpcTaskWindow:checkAutoGet()
	local now = getTime();
	if self.endTime ~= nil and now < self.endTime then
		self.autoContinueTxt.text = LanUtil.formateStr(LanUtil.getValue(122902), tostring(math.ceil(self.endTime - now)));
		self.autoContinueTxt:setEnable(true);
	else
		self:onGetRewardClick();
		self.autoContinueTxt:setEnable(false);
	end
end

function Lua_NpcTaskWindow:checkShowGetRewardArrow()
	if self.taskVo == nil or self.taskVo.status ~= Lua_TaskDefine.DELIVERED then
		if self.arrowItem ~= nil then
			self.arrowItem:setEnable(false);
		end
		if self.btnEffect ~= nil then
			self.btnEffect:setEnable(false);
		end
		return;
	end
	
	if self.arrowItem == nil then
		 self.arrowItem = Lua_GuideArrow.new(self.content, "talk_arrow");
	else
		self.arrowItem:setEnable(true);
	end
	self.arrowItem:setArrowDir(4);
	self.arrowItem:setArrowRenderQ(self.npcWinBg, 2, 2);
	self.arrowItem:setLocation(610, -285, 0);
	self.arrowItem:setEnable(false);
	
	if self.btnEffect == nil then
		self.btnEffect = UICreate.createUIEffect(self.content, nil, nil, 0, 0);		
		self.btnEffect:setLocation(420, -289, -100);
		self.btnEffect.circulate = true;
	end
	self.btnEffect:setUrl("/effects/scsEffects/anniutexiao", "anniutexiao");
	self:delayRender();
end

function Lua_NpcTaskWindow:delayRender()
	if self.btnEffect ~= nil then
		self.btnEffect:SetRenderQueue(self.npcWinBg, 5, 2, false);
	end
end

function Lua_NpcTaskWindow:hide()
	self:superCall("hide");
	DataCenter.taskHook:refreshLastRoleActive();
end

function Lua_NpcTaskWindow:onGetRewardClick()
	if self.taskVo.video_url ~= nil then
		Lua_WindowUtil.openWin("Lua_TaskVideoWindow", WinParam.ACTION_OPEN, self.taskVo);
		self:hide();
		return;
	end

	local cmd;
	if self.taskVo.status == Lua_TaskDefine.ACCEPT  then
		cmd= getProtoMsg("Proto11400326");
		cmd.task_id = self.taskVo.taskId;
		sendMsg(11400326, cmd);
	elseif self.taskVo.status == Lua_TaskDefine.DELIVERED then
		cmd = getProtoMsg("Proto11400328");
		cmd.task_id = self.taskVo.taskId;
		sendMsg(11400328, cmd);
	elseif getLanType() == 2 and self.taskVo.taskType == Lua_TaskDefine.ROUTINE then
		self.taskVo.status=Lua_TaskDefine.DELIVERED;
		Lua_WindowUtil.openWin("Lua_DailyRoutineWindow",WinParam.ACTION_OPEN,self.taskVo);
	end
	self:hide();
end

function Lua_NpcTaskWindow:dispose()
	if self.rItem ~= nil then
		self.rItem:dispose();
		self.rItem = nil;
	end

	self:superCall("dispose");
end